@@ -168,9 +168,9 @@ my %template = (
 	left   => [  "╷╴"  ,
 		     "╷ "  ,
 		     "╶╶" ],
-	center => [  "╷╴"  ,
-		     "╷ "  ,
-		     "╶╶" ],
+	center => [  "╴╴"  ,
+		     "╵ "  ,
+		     "└╶" ],
 	right  => [ "╴"    ,
 		    "╵"    ,
 		    "╵"   ],
